@@ -1,14 +1,14 @@
 use strict;
 use warnings;
-package JSON::Schema::Tiny; # git description: v0.015-5-gab3d70e
+package JSON::Schema::Tiny; # git description: v0.016-2-g931de61
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema, minimally
 # KEYWORDS: JSON Schema data validation structure specification tiny
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use 5.020;  # for unicode_strings, signatures, postderef features
-use experimental qw(signatures postderef args_array_with_signatures);
+use experimental 0.026 qw(signatures postderef args_array_with_signatures);
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
@@ -1274,7 +1274,7 @@ JSON::Schema::Tiny - Validate data against a schema, minimally
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
